=========
Changelog
=========

0.3.0 - 2009-12-30
==================

* First release on the python package index.

0.9.1 - 2010-02-04
==================

* Adding support for django current trunk which will be 1.2

0.9.2 - 2010-02-04
==================

* Fixing bug with clones of ``PublicQuerySet``. It didn't filter for public
  attributes.
